{% extends 'base.html' %}

{% load i18n %}
{% load url from future %}
{% load compress %}

{% block title %}{% trans 'Alarm Definitions' %}{% endblock %}
{% block css %}
    {% include "_stylesheets.html" %}
    <link href='{{ STATIC_URL }}monitoring/css/ng-tags-input.css' type="text/css" rel="stylesheet"/>
{% endblock %}

{% block page_header %}
{% include "horizon/common/_page_header.html" with title=_("Alarm Definitions") %}
{% endblock page_header %}

{% block main %}
    {{ table.render }}
<div class="pagination">
    <span class="step-links">
        {% if prev_page_offset != None %}
            <a href="?page_offset={{ prev_page_offset }}" class="btn btn-default btn-sm" style="position:relative;top:-35px;">{% trans 'Previous Page' %}</a>
        {% endif %}
        {% if page_offset %}
            <a href="?page_offset={{ page_offset}}" class="btn btn-default btn-sm" style="position:relative;top:-35px;">{% trans 'Next Page' %}</a>
        {% endif %}
    </span>
</div>
{% endblock %}
